
# What I need to do for this:
# 1. Choose the correct inputs
# 2. Scrape the website for the html and image source
# 3. Download the image with urlib or requests and save as a png
from selenium import webdriver
from selenium.webdriver.support.ui import Select
from selenium.webdriver.chrome.options import Options
from selenium.webdriver.common.by import By
from chromedriver_py import binary_path
import urllib.request
import argparse
import sys
import os
import pandas as pd

from tqdm import tqdm
from datetime import datetime, timedelta
import time
import json
import requests
import re

def main(basetime, level, region, validtime, outdir):

    url = f'https://charts.ecmwf.int/products/medium-t-z?base_time={basetime}&level={level}&projection=opencharts_{region}&valid_time={validtime}'

    options = Options()
    options.headless = True
    options.add_argument("--no-sandbox")
    svc = webdriver.ChromeService(executable_path=binary_path)
    driver = webdriver.Chrome(service=svc, options=options)

    driver.get(url)


    #elements = driver.find_elements(By.CSS_SELECTOR, '[alt="Mon 22 Apr 2024 12 UTC (T+12)"]')
    elements = driver.find_elements(By.TAG_NAME, "img")

    print(elements)
    for i, img in enumerate(tqdm(elements)):
        img_src = img.get_attribute("src")
        name = f'{outdir}/ecmwf_plot_20240422{"{0:02}".format(i*3)}_{level}hPa.png'
        print(img_src)

        urllib.request.urlretrieve(img_src, name)
        


    driver.close()

def request_metadata(date, variable, region, level, outdir):
    """
    Downloading in a different way quering the metadata to get the json and then get the png
    """

    # Split this up so we can specify region, level and variable
    for i in range(0, 75, 3):
        # Need to figure out the basetime and then the validtime
        basetime_d = datetime.strptime(date, "%Y%m%d%H")
        basetime = basetime_d.strftime("%Y-%m-%dT%H")
        validtime_d = basetime_d + timedelta(seconds=i*3600)
        validtime = validtime_d.strftime("%Y-%m-%dT%H")
        print("Basetime: {}".format(basetime))
        print("Validtime: {}".format(validtime))
        if level == "None":
            url = "https://charts.ecmwf.int/opencharts-api/v1/products/medium-{}/?valid_time={}%3A00%3A00Z&base_time={}%3A00%3A00Z&projection=opencharts_{}".format(variable, validtime, basetime, region)
            name = f'{outdir}/{variable}_{date[:-2]}_{"{0:03}".format(i)}.png'
        else:
            url = "https://charts.ecmwf.int/opencharts-api/v1/products/medium-{}/?valid_time={}%3A00%3A00Z&base_time={}%3A00%3A00Z&projection=opencharts_{}&level={}".format(variable, validtime, basetime, region, level)
            name = f'{outdir}/{variable}_{date[:-2]}_{"{0:03}".format(i)}_{level}hPa.png'
        print(url)
        r = requests.get(url)
        data = r.text
    
        jdata = json.loads(data)
        img_src = jdata["data"]["link"]["href"]
        
        urllib.request.urlretrieve(img_src, name)
        time.sleep(10)

def getOptions(args=sys.argv[1:]):
    parser = argparse.ArgumentParser(description="Parses command.")
    parser.add_argument("-e", "--enddate", type=str, help="Enddate")
    parser.add_argument("-s", "--startdate", type=str, help="Startdate")
    parser.add_argument("-v", "--variable", type=str, help="Variable we are interested in")
    parser.add_argument("-l", "--level", type=str, help="Pressure level")
    parser.add_argument("-r", "--region", type=str, help="Region")

    options = parser.parse_args(args)
    return options
    

    
    
#TODO
#1.Parse arguments
#2.Run through dates provided, create dir if not already there
#3. Move to a place in esarchive

if __name__ == "__main__":
    options = getOptions()
    level = options.level
    region = options.region
    variable = options.variable
    startdate = options.startdate
    enddate = options.enddate

    for date in pd.date_range(startdate, enddate):
        date = date.strftime("%Y%m%d")
        outdir = f"/esarchive/recon/ecmwf/ecmwf_plots/original_files/{variable}/{region}/{date}"
        if not os.path.exists(outdir):
            os.makedirs(outdir)
        basetime = f"{date}00"
        validtime = basetime # Need to change this if we want more timesteps

        request_metadata(basetime, variable, region, level, outdir)



